@@ -16,10 +16,9 @@
 # Caner Candan <caner@candan.fr>, http://caner.candan.fr
 #
 
-MANAGED_API=["BASIC_MERKLED_API", "BMAS"]
 
-__author__      = 'Caner Candan & inso & vit'
-__version__     = '0.40.3'
-__nonsense__    = 'duniter'
+__author__ = "Caner Candan & inso & vit"
+__version__ = "0.57.0"
+__nonsense__ = "duniter"
 
-from . import api, documents, key
\ No newline at end of file
+from . import api, documents, key
