@@ -1,3 +1,4 @@
-from .signing_key import SigningKey, ScryptParams
+from .signing_key import SigningKey
 from .verifying_key import VerifyingKey
-from .encryption_key import SecretKey, PublicKey
\ No newline at end of file
+from .encryption_key import SecretKey, PublicKey
+from .ascii_armor import AsciiArmor
